"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("../types");
const i18n_1 = require("../i18n");
const convert_1 = require("../convert");
const errors_1 = require("../errors");
var DeployStatusEnum;
(function (DeployStatusEnum) {
    DeployStatusEnum["Succeeded"] = "Succeeded";
    DeployStatusEnum["InProgress"] = "InProgress";
    DeployStatusEnum["Pending"] = "Pending";
    DeployStatusEnum["Failed"] = "Failed";
})(DeployStatusEnum = exports.DeployStatusEnum || (exports.DeployStatusEnum = {}));
exports.DEFAULT_API_OPTIONS = {
    rollbackOnError: true,
    ignoreWarnings: false,
    checkOnly: false,
    singlePackage: true
};
/* eslint-disable @typescript-eslint/no-unused-vars */
class MetadataApi extends types_1.BaseApi {
    retrieveWithPaths(options) {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('Method not implemented.');
        });
    }
    retrieve(options) {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('Method not implemented.');
        });
    }
    deploy(components, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const metadataComponents = Array.isArray(components) ? components : [components];
            const converter = new convert_1.MetadataConverter();
            const conversionCall = yield converter.convert(metadataComponents, 'metadata', { type: 'zip' });
            const deployID = yield this.metadataDeployID(conversionCall.zipBuffer, options);
            const deploy = this.metadataDeployStatusPoll(deployID, options);
            let files = [];
            metadataComponents.forEach(file => {
                files = files.concat(file.walkContent());
                files.push(file.xml);
            });
            (yield deploy).outboundFiles = files;
            return deploy;
        });
    }
    deployWithPaths(paths, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const components = this.registry.getComponentsFromPath(paths);
            return this.deploy(components, options);
        });
    }
    metadataDeployID(zipBuffer, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!options || !options.apiOptions) {
                options = {
                    apiOptions: exports.DEFAULT_API_OPTIONS
                };
            }
            else {
                for (const [property, value] of Object.entries(exports.DEFAULT_API_OPTIONS)) {
                    if (!(property in options.apiOptions)) {
                        //@ts-ignore ignore while dynamically building the defaults
                        options.apiOptions[property] = value;
                    }
                }
            }
            const result = yield this.connection.metadata.deploy(zipBuffer, options.apiOptions);
            return result.id;
        });
    }
    metadataDeployStatusPoll(deployID, options, interval = 100) {
        return __awaiter(this, void 0, void 0, function* () {
            const timeout = !options || !options.wait ? 10000 : options.wait;
            const endTime = Date.now() + timeout;
            // @ts-ignore
            const checkDeploy = (resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                const result = yield this.connection.metadata.checkDeployStatus(deployID);
                switch (result.status) {
                    case "Succeeded" /* Succeeded */:
                        resolve(result);
                        break;
                    case "Failed" /* Failed */:
                        const deployError = new errors_1.DeployError('md_request_fail', result.errorMessage);
                        reject(deployError);
                        break;
                    case "InProgress" /* InProgress */:
                    case "Pending" /* Pending */:
                    case '':
                    default:
                        if (Date.now() < endTime) {
                            setTimeout(checkDeploy, interval, resolve, reject);
                        }
                        else {
                            reject(new Error(i18n_1.nls.localize('md_request_timeout')));
                        }
                }
            });
            return new Promise(checkDeploy);
        });
    }
}
exports.MetadataApi = MetadataApi;
//# sourceMappingURL=metadataApi.js.map