/// <reference types="node" />
import { pipeline as cbPipeline, Readable, Transform, Writable } from 'stream';
import { RegistryAccess, SourceComponent } from '../metadata-registry';
import { SfdxFileFormat, SourcePath, WriterFormat } from '../types';
export declare const pipeline: typeof cbPipeline.__promisify__;
export declare class ComponentReader extends Readable {
    private currentIndex;
    private components;
    constructor(components: SourceComponent[]);
    _read(): void;
}
export declare class ComponentConverter extends Transform {
    private targetFormat;
    private registryAccess;
    constructor(targetFormat: SfdxFileFormat, registryAccess: RegistryAccess);
    _transform(chunk: SourceComponent, encoding: string, callback: (err: Error, data: WriterFormat) => void): void;
}
export declare abstract class ComponentWriter extends Writable {
    protected rootDestination?: SourcePath;
    constructor(rootDestination?: SourcePath);
}
export declare class StandardWriter extends ComponentWriter {
    constructor(rootDestination: SourcePath);
    _write(chunk: WriterFormat, encoding: string, callback: (err?: Error) => void): Promise<void>;
}
export declare class ZipWriter extends ComponentWriter {
    private zip;
    private buffers;
    constructor(rootDestination?: SourcePath);
    _write(chunk: WriterFormat, encoding: string, callback: (err?: Error) => void): Promise<void>;
    _final(callback: (err?: Error) => void): Promise<void>;
    addToZip(contents: string | Readable | Buffer, path: SourcePath): void;
    private getOutputStream;
    readonly buffer: Buffer | undefined;
}
