"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const errors_1 = require("../../errors");
const default_1 = require("./default");
var TransformerId;
(function (TransformerId) {
    TransformerId["Standard"] = "standard";
})(TransformerId || (TransformerId = {}));
class MetadataTransformerFactory {
    constructor(registry) {
        this.registry = registry;
    }
    getTransformer(component) {
        const type = component.type;
        const transformerId = this.registry.strategies.hasOwnProperty(type.id)
            ? this.registry.strategies[type.id].transformer
            : undefined;
        switch (transformerId) {
            case "standard" /* Standard */:
            case undefined:
                return new default_1.DefaultTransformer(component);
            default:
                throw new errors_1.RegistryError('error_missing_transformer', [type.name, transformerId]);
        }
    }
}
exports.MetadataTransformerFactory = MetadataTransformerFactory;
//# sourceMappingURL=metadataTransformerFactory.js.map