"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const utils_1 = require("../../utils");
const baseSourceAdapter_1 = require("./baseSourceAdapter");
const errors_1 = require("../../errors");
const path_1 = require("../../utils/path");
/**
 * Handles types with a single content file with a matching file extension.
 *
 * __Example Types__:
 *
 * ApexClass, ApexTrigger, ApexComponent
 *
 * __Example Structure__:
 *
 * ```text
 * foos/
 * ├── foobar.ext
 * ├── foobar.ext-meta.xml
 *```
 */
class MatchingContentSourceAdapter extends baseSourceAdapter_1.BaseSourceAdapter {
    getRootMetadataXmlPath(trigger) {
        return `${trigger}${utils_1.META_XML_SUFFIX}`;
    }
    populate(component, trigger) {
        let sourcePath;
        if (component.xml === trigger) {
            const fsPath = this.removeMetaXmlSuffix(trigger);
            if (this.tree.exists(fsPath)) {
                sourcePath = fsPath;
            }
        }
        else if (this.fileSuffixIndexed(trigger)) {
            sourcePath = trigger;
        }
        if (!sourcePath) {
            throw new errors_1.ExpectedSourceFilesError(this.type, trigger);
        }
        else if (this.forceIgnore.denies(sourcePath)) {
            throw new errors_1.UnexpectedForceIgnore('error_no_source_ignore', [this.type.name, sourcePath]);
        }
        component.content = sourcePath;
        return component;
    }
    removeMetaXmlSuffix(fsPath) {
        return fsPath.slice(0, fsPath.lastIndexOf(utils_1.META_XML_SUFFIX));
    }
    fileSuffixIndexed(fsPath) {
        return !!this.registry.suffixes[path_1.extName(fsPath)];
    }
}
exports.MatchingContentSourceAdapter = MatchingContentSourceAdapter;
//# sourceMappingURL=matchingContentSourceAdapter.js.map