import { MetadataRegistry, MetadataTransformer, MetadataType, TreeContainer } from '../types';
import { SourceComponent } from './sourceComponent';
/**
 * Resolver for metadata type and component objects.
 */
export declare class RegistryAccess {
    readonly registry: MetadataRegistry;
    private forceIgnore;
    private metadataTransformerFactory;
    private sourceAdapterFactory;
    private tree;
    /**
     * @param registry Custom registry data
     * @param tree `TreeContainer` to traverse with
     */
    constructor(registry?: MetadataRegistry, tree?: TreeContainer);
    getApiVersion(): string;
    /**
     * Get a metadata type definition.
     *
     * @param name Name of the metadata type
     */
    getTypeFromName(name: string): MetadataType;
    /**
     * Get the metadata component(s) from a file path.
     *
     * @param fsPath File path for a piece of metadata
     */
    getComponentsFromPath(fsPath: string): SourceComponent[];
    getTransformer(component: SourceComponent): MetadataTransformer;
    private getComponentsFromPathRecursive;
    private resolveComponent;
    private resolveType;
}
