import { SourcePath, VirtualDirectory, TreeContainer } from '../types';
/**
 * An extendable base class for implementing the `TreeContainer` interface
 */
export declare abstract class BaseTreeContainer implements TreeContainer {
    find(fileType: 'content' | 'metadata', fullName: string, dir: SourcePath): SourcePath | undefined;
    abstract exists(path: SourcePath): boolean;
    abstract isDirectory(path: SourcePath): boolean;
    abstract readDirectory(path: SourcePath): string[];
}
export declare class NodeFSTreeContainer extends BaseTreeContainer {
    isDirectory(fsPath: SourcePath): boolean;
    exists(fsPath: SourcePath): boolean;
    readDirectory(fsPath: SourcePath): string[];
}
export declare class VirtualTreeContainer extends BaseTreeContainer {
    private tree;
    constructor(virtualFs: VirtualDirectory[]);
    isDirectory(fsPath: string): boolean;
    exists(fsPath: string): boolean;
    readDirectory(fsPath: string): string[];
    private populate;
}
